==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/tabs/translations/tabs_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>Tabs</source>
        <translation>Karty</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Look</source>
        <translation>Wygląd</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Skróty</translation>
    </message>
    <message>
        <source>Move tab left</source>
        <translation>Przesuń kartę w lewo</translation>
    </message>
    <message>
        <source>Move tab right</source>
        <translation>Przesuń kartę w prawo</translation>
    </message>
    <message>
        <source>Switch to previous tab</source>
        <translation>Przełącz do poprzedniej karty</translation>
    </message>
    <message>
        <source>Switch to next tab</source>
        <translation>Przełącz do następnej karty</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Rozmowa</translation>
    </message>
    <message>
        <source>Enable tabs in chat window</source>
        <translation>Włącz karty w oknie rozmowy</translation>
    </message>
    <message>
        <source>With this option, each chat will be opened in a separate tab in single window</source>
        <translation>Wszystkie rozmowy będą otwierane w tym samym oknie, ale w różnych kartach</translation>
    </message>
    <message>
        <source>Closing window closes current tab only</source>
        <translation>Zamknij tylko aktualną kartę przy zamykaniu okna</translation>
    </message>
    <message>
        <source>When enabled, closing chat window will cause closing only current tab, instead of all tabs and the window itself</source>
        <translation>Przy włączonej tej opcji zamykanie okna będzie skutkowało zamknięciem tylko aktualnej karty a nie wszystkich kart wraz z oknem</translation>
    </message>
    <message>
        <source>Tab bar position</source>
        <translation>Pozycja paska kart</translation>
    </message>
    <message>
        <source>Choose where you want the tab bar to be placed in chat window</source>
        <translation>Wybierz miejsce, w którym będzie się znajdował pasek kart</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Góra</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Dół</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Zachowanie</translation>
    </message>
    <message>
        <source>Reopen closed tab</source>
        <translation>Otwórz zamkniętą kartę</translation>
    </message>
    <message>
        <source>Show &apos;Open chat&apos; button</source>
        <translation>Pokazuj przycisk &apos;Otwórz rozmowę&apos;</translation>
    </message>
    <message>
        <source>Show common &apos;Close Tab&apos; button on tab bar</source>
        <translation>Pokazuj wspólny przycisk &apos;Zamkij kartę&apos; na pasku kart</translation>
    </message>
    <message>
        <source>Show &apos;Close&apos; button on each tab</source>
        <translation>Pokazuj przyciski &apos;Zamknij&apos; na każdej karcie</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>New message received, close window anyway?</source>
        <translation>Otrzymano nową wiadomość, zamknąć mimo to?</translation>
    </message>
    <message>
        <source>Recent Chats</source>
        <translation>Ostatnie rozmowy</translation>
    </message>
    <message>
        <source>Open Chat with...</source>
        <translation>Rozpocznij rozmowę z ...</translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation>Karty</translation>
    </message>
    <message>
        <source>Close Tab</source>
        <translation>Zamknij kartę</translation>
    </message>
    <message>
        <source>Close window</source>
        <translation>Zamknij okno</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
</context>
<context>
    <name>TabsManager</name>
    <message>
        <source>Chat in New Window</source>
        <translation>Rozmawiaj w nowym oknie</translation>
    </message>
    <message>
        <source>Chat in New Tab</source>
        <translation>Rozmawiaj w nowej karcie</translation>
    </message>
    <message>
        <source>Attach Chat to Tabs</source>
        <translation>Dołącz rozmowę do kart</translation>
    </message>
    <message>
        <source>Detach</source>
        <translation>Odłącz</translation>
    </message>
    <message>
        <source>Detach all</source>
        <translation>Odłącz wszystkie</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Close all</source>
        <translation>Zamknij wszystkie</translation>
    </message>
    <message>
        <source>Close other tabs</source>
        <translation>Zamknij pozostałe karty</translation>
    </message>
    <message>
        <source>Reopen closed tab</source>
        <translation>Otwórz zamkniętą kartę</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/tabs/translations/tabs_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Tabs</source>
        <translation>Karty</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Look</source>
        <translation>Wygląd</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Skróty</translation>
    </message>
    <message>
        <source>Move tab left</source>
        <translation>Przesuń kartę w lewo</translation>
    </message>
    <message>
        <source>Move tab right</source>
        <translation>Przesuń kartę w prawo</translation>
    </message>
    <message>
        <source>Switch to previous tab</source>
        <translation>Przełącz do poprzedniej karty</translation>
    </message>
    <message>
        <source>Switch to next tab</source>
        <translation>Przełącz do następnej karty</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Rozmowa</translation>
    </message>
    <message>
        <source>Enable tabs in chat window</source>
        <translation>Włącz karty w oknie rozmowy</translation>
    </message>
    <message>
        <source>With this option, each chat will be opened in a separate tab in single window</source>
        <translation>Wszystkie rozmowy będą otwierane w tym samym oknie, ale w różnych kartach</translation>
    </message>
    <message>
        <source>Closing window closes current tab only</source>
        <translation>Zamknij tylko aktualną kartę przy zamykaniu okna</translation>
    </message>
    <message>
        <source>When enabled, closing chat window will cause closing only current tab, instead of all tabs and the window itself</source>
        <translation>Przy włączonej tej opcji zamykanie okna będzie skutkowało zamknięciem tylko aktualnej karty a nie wszystkich kart wraz z oknem</translation>
    </message>
    <message>
        <source>Tab bar position</source>
        <translation>Pozycja paska kart</translation>
    </message>
    <message>
        <source>Choose where you want the tab bar to be placed in chat window</source>
        <translation>Wybierz miejsce, w którym będzie się znajdował pasek kart</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Góra</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Dół</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Zachowanie</translation>
    </message>
    <message>
        <source>Reopen closed tab</source>
        <translation>Otwórz zamkniętą kartę</translation>
    </message>
    <message>
        <source>Show &apos;Open chat&apos; button</source>
        <translation>Pokazuj przycisk &apos;Otwórz rozmowę&apos;</translation>
    </message>
    <message>
        <source>Show common &apos;Close Tab&apos; button on tab bar</source>
        <translation>Pokazuj wspólny przycisk &apos;Zamkij kartę&apos; na pasku kart</translation>
    </message>
    <message>
        <source>Show &apos;Close&apos; button on each tab</source>
        <translation>Pokazuj przyciski &apos;Zamknij&apos; na każdej karcie</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>New message received, close window anyway?</source>
        <translation>Otrzymano nową wiadomość, zamknąć mimo to?</translation>
    </message>
    <message>
        <source>Recent Chats</source>
        <translation>Ostatnie rozmowy</translation>
    </message>
    <message>
        <source>Open Chat with...</source>
        <translation>Rozpocznij rozmowę z ...</translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation>Karty</translation>
    </message>
    <message>
        <source>Close Tab</source>
        <translation>Zamknij kartę</translation>
    </message>
    <message>
        <source>Close window</source>
        <translation>Zamknij okno</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
</context>
<context>
    <name>TabsManager</name>
    <message>
        <source>Chat in New Window</source>
        <translation>Rozmawiaj w nowym oknie</translation>
    </message>
    <message>
        <source>Chat in New Tab</source>
        <translation>Rozmawiaj w nowej karcie</translation>
    </message>
    <message>
        <source>Attach Chat to Tabs</source>
        <translation>Dołącz rozmowę do kart</translation>
    </message>
    <message>
        <source>Detach</source>
        <translation>Odłącz</translation>
    </message>
    <message>
        <source>Detach all</source>
        <translation>Odłącz wszystkie</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Close all</source>
        <translation>Zamknij wszystkie</translation>
    </message>
    <message>
        <source>Close other tabs</source>
        <translation>Zamknij pozostałe karty</translation>
    </message>
    <message>
        <source>Reopen closed tab</source>
        <translation>Otwórz zamkniętą kartę</translation>
    </message>
</context>
</TS>
